@@ -12,25 +12,26 @@ testfile3 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MBRS\MBR
 testfile4 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCD\MCD_0.xlsx"
 testfile5 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCO\MCO_0.xlsx"
 testfile6 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MO_1AP\MO_1AP_0.xlsx"
+testfile7 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCBXH\MCBXH_CopperWedges_0.xlsx"
 
 ledetFolder = 'C:\cernbox\LEDET\\'
 ledetExe = 'LEDET_v1_07_02_02_25May2020.exe'
-MagnetName = 'MBRC'
 
 def CompleteRun():
     start = time.time()
     a = ParametersLEDET()
-    a.readLEDETExcel(testfile6)
+    a.readLEDETExcel(testfile7)
     Sw = MinMaxSweep(a, 6)
-    MagnetName = 'MO_1AP'
+    MagnetName = 'MCBXH_CopperWedges'
+
     ##8mag
     # Sw.addParameterToSweep('l_magnet', 2.56, 4.8)
     # Sw.addParameterToSweep('f_ro_eff_inGroup', 1, 3)
     # Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
     ##13mag
-    Sw.addParameterToSweep('l_magnet', 4.16, 5.2)
-    Sw.addParameterToSweep('f_ro_eff_inGroup', 1, 3)
-    Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
+    # Sw.addParameterToSweep('l_magnet', 4.16, 5.2)
+    # Sw.addParameterToSweep('f_ro_eff_inGroup', 1, 3)
+    # Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
 
     # ##MBX
     # Sw.addParameterToSweep('f_ro_eff_inGroup', 1, 3, basePoints = 3)
@@ -44,6 +45,11 @@ def CompleteRun():
     # Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
     # Sw.addHeliumCrossSection(3, 6, basePoints=4)
 
+    ## MCBXH_CopperWedges
+    Sw.addParameterToSweep('f_ro_eff_inGroup', 0.5, 2.5)
+    Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
+    Sw.addQuenchSweep("tStartQuench",[1,1,1,1,1,1],[-0.2, -0.21, -0.22, -0.23, -0.24, -0.25])
+
     Sw.generatePermutations()
     end = time.time()
     print("Time:", end-start)
@@ -51,12 +57,14 @@ def CompleteRun():
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MBRC\\Input\\")
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MCD\\Input\\")
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MCO\\Input\\")
-    Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MO_1AP\\Input\\")
+    # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MO_1AP\\Input\\")
+    # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MCBXH_CopperWedges\\Input\\")
+
     end = time.time()
     print("Time:", end - start)
     print("Preparation done")
 
-    # RunSimulations(ledetFolder, ledetExe, 'MCO', RunSimulations=False)
+    # RunSimulations(ledetFolder, ledetExe, 'MCBXH_CopperWedges', RunSimulations=False)
     # EvaluateSimulations("C:\\cernbox\\LEDET\\LEDET\\MCO\\Output\\Txt Files", 'MCO',
     #                     'C:\\cernbox\\Validation_MCDO\\Exp Data\\RCO.A56B1_2018-03-16_PM_I_A_AutoAlign.csv',
     #                     Sw, Mat=False, SkipAlign=True)
@@ -68,9 +76,12 @@ def CompleteRun():
     #                     Sw, Mat=False, SkipAlign=True)
     # EvaluateSimulations('C:\\cernbox\\Validation_MO\\Validation\\LEDET\\FullB2', 'MO_1AP', 'C:\\cernbox\\LHC-SM-API\\ROD_ROF\\ROD.A12B2_PM_I_A.csv',
                         # Sw, Mat=False)
-    EvaluateSimulations('C:\\cernbox\\Validation_MO\\Validation\\LEDET\\FullB1', 'MO_1AP',
-                        'C:\\cernbox\\LHC-SM-API\\ROD_ROF\\ROD.A12B1_PM_I_A.csv',
-                         Sw, Mat=False)
+    # EvaluateSimulations('C:\\cernbox\\Validation_MO\\Validation\\LEDET\\FullB1', 'MO_1AP',
+    #                     'C:\\cernbox\\LHC-SM-API\\ROD_ROF\\ROD.A12B1_PM_I_A.csv',
+    #                      Sw, Mat=False)
+    # EvaluateSimulations('C:\\cernbox\\LEDET\\LEDET\\MCBXH_CopperWedges\\Output\\Txt Files', 'MCBXH_CopperWedges',
+    #                     'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXH1.R1_2018-03-11_PM_I_ARAW.csv',
+    #                      Sw, Mat=False)
 
 def AutomaticRun():
     LEDETFolder = 'C:\\cernbox\LEDET\\LEDET_SimulationFiles_Quench'
@@ -98,11 +109,16 @@ def AutomaticRun():
 CompleteRun()
 
 # a = ParametersLEDET()
-# a.readLEDETExcel(testfile1)
-# Sw = MinMaxSweep(a, 1)
-# MagnetName = 'MBRC'
+# a.readLEDETExcel(testfile7)
+# Sw = MinMaxSweep(a, 3)
+# MagnetName = 'MCBXH_CopperWedges'
+# Sw.addParameterToSweep('l_magnet', 4.16, 5.2)
+# Sw.addParameterToSweep('f_ro_eff_inGroup', 1, 3)
+# Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
+# Sw.addQuenchSweep("tStartQuench",[0,2],[-3,5])
+# Sw.addQuenchSweep("tStartQuench",[[1,4],[2,5]],[[-3,5],[1,2]])
 # Sw.addHeliumCrossSection(3, 6, basePoints=4)
 # Sw.generatePermutations()
-# Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MBRC\\Input\\")
+# Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEST-DELTE\\")
 
 # x = AutomaticRun()
