@@ -64,20 +64,30 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
                                 try:
                                     idxR = k.index(' R_CoilSections_1')
                                     R = np.array(cols[idxR])
+                                    T = np.array(cols[idxT])
                                     RLedet = np.append([num], np.array(R))
                                     if RData.size == 0:
                                         RData = RLedet.astype(float)
+                                    elif not T.size == SimData[0, :].size:
+                                        RL = interp1d(T, np.array(RLedet[1:]), kind='cubic')
+                                        RLedet = RL(SimData[0, :])
                                     RData = np.vstack((RData, RLedet.astype(float)))
                                 except:
+                                    print("Error reading R, no abort")
                                     pass
                                 T = np.array(cols[idxT])
                                 ISim = np.array(cols[idxI])
                             if not flag_BasePoints:
                                 BasePoints = T.shape[0]
                                 SimData = np.append([0], T)
-                                flag_BasePoints = 1
+                            #Check if size is the same
+                            if flag_BasePoints:
+                                if not T.size == SimData[0,:].size:
+                                    IL = interp1d(T, np.array(ISim), kind='cubic')
+                                    ISim = IL(SimData[0,1:])
                             ILedet = np.append([num], np.array(ISim))
                             SimData = np.vstack((SimData, ILedet.astype(float)))
+                            flag_BasePoints = 1
             except:
                  print("Reading of " + item + " was not successful")
                  continue
@@ -131,30 +141,20 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
     except:
         print("Interpolating Data was not sucessful.")
         print("Start-Point of Tmeas", Tmeas[idx_low]+abs(Tmeas[idx_low]), ", Start-Point of Tsim:", SimData[0, 1])
-        print("End-Point of Tmeas", Tmeas[idx_up] + abs(Tmeas[idx_low]), ", End-Point of Tsim:",
-              SimData[0, -1])
+        print("End-Point of Tmeas", Tmeas[idx_up] + abs(Tmeas[idx_low]), ", End-Point of Tsim:", SimData[0, -1])
         return
 
-    Arr = []
     SweepMatrix = SweepObject.SweepMatrix
-
     #Calculate MSE
     for i in range(1, SimData.shape[0]):
         MSESims[i-1, 0] = SimData[i, 0]
         MSESims[i-1, 1] = (np.square(SimData[i, 1:] - Imeas2[:])).mean(axis=0)
-        Arr.append([i-1, SweepMatrix[i-1,0],SweepMatrix[i-1,1],SweepMatrix[i-1,2],MSESims[i-1, 1]])
 
     # Calculate largest Deviation
     for i in range(1, SimData.shape[0]):
          LDSims[i - 1, 0] = SimData[i, 0]
          LDSims[i - 1, 1] = np.amax(abs(SimData[i, 1:].astype(float) - Imeas2[:]))
 
-    # f = open('C:\cernbox\AutoAnalysis\TestData.csv', 'w')
-    # with f:
-    #     writer = csv.writer(f)
-    #     for row in Arr:
-    #         writer.writerow(row)
-
     print("Best Fit for Meas-StartIDX: ", idx_low)
     BestFit = np.argsort(MSESims[:, 1])
     print("Best fitting simulations for MSE: ")
@@ -179,7 +179,7 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
 
     for i in range(SweepedParameters):
         for j in range(len(BestFit)):
-            AbMatrix[i, j] = SweepMatrix[BestFit[j],i]
+            AbMatrix[i, j] = SweepMatrix[BestFit[j]+1,i]
         MaxVar[i] = np.var(SweepMatrix[:, i])
         Var[i] = np.var(AbMatrix[i, :])/MaxVar[i]
 
@@ -244,12 +244,17 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
         opacity = 0.5
         dec = 0.4/NumberBest
         colors = cm.spring
-        ax.plot(SimData[0, 1:].astype(float), SimData[BestFit[0], 1:].astype(float), color=colors(2*opacity),
+        TotLength = int(len(SimData[0,:])/2)
+        LengthStep = int(TotLength/len(BestFit))
+        ax.plot(SimData[0, 1:].astype(float), SimData[BestFit[0]+1, 1:].astype(float), color=colors(2*opacity),
                 alpha=opacity, label='_nolegend_')
+        ax.text(SimData[0, TotLength].astype(float),SimData[BestFit[0]+1, TotLength].astype(float), str(0), alpha = opacity)
         for i in range(1,len(BestFit)):
             opacity = (opacity - dec)
-            ax.plot(SimData[0, 1:].astype(float), SimData[BestFit[i], 1:].astype(float), color=colors(2*opacity),
+            ax.plot(SimData[0, 1:].astype(float), SimData[BestFit[i]+1, 1:].astype(float), color=colors(2*opacity),
                     alpha=opacity, label='_nolegend_')
+            ax.text(SimData[0, TotLength+i*LengthStep].astype(float), SimData[BestFit[i]+1, TotLength+i*LengthStep].astype(float), str(i),
+                    alpha=opacity)
         sm = plt.cm.ScalarMappable(cmap=colors)
         cbar = plt.colorbar(sm)
         cbar.set_ticks([1])
@@ -264,8 +269,11 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
         verts = []
         zs = [1.0, 2.0, 3.0]
         xs = (np.concatenate([[x[0]], x[:], [x[-1]]])-x[0])/(x[-1]-x[0])
+        xb = SweepMatrix[BestFit[0]+1,0]
         ys = (np.concatenate([[y[0]], y[:], [y[-1]]])-y[0])/(y[-1]-y[0])
+        yb = SweepMatrix[BestFit[0]+1,1]
         ks = (np.concatenate([[k[0]], k[:], [k[-1]]])-k[0])/(k[-1]-k[0])
+        kb = SweepMatrix[BestFit[0]+1,2]
         xMS = np.concatenate([[0], 1/MSESims[D1.astype(int), 1], [0]])
         yMS = np.concatenate([[0], 1/MSESims[D2.astype(int), 1], [0]])
         kMS = np.concatenate([[0], 1/MSESims[D3.astype(int), 1], [0]])
@@ -278,13 +286,24 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
         poly.set_alpha(0.7)
         zs = [1.0, 2.0, 3.0]
         ax.add_collection3d(poly, zs=zs, zdir='y')
-        ax.set_xlabel('Values [0=Min, 1=Max Value]', fontsize =11)
+        ax.set_xlabel('Values [0=Min, 1=Max Value]', fontsize =14, labelpad=10)
         ax.set_xlim3d(0, 1)
-        ax.set_ylabel('Parameters', fontsize = 11)
+        ax.set_ylabel('Parameters', fontsize = 14,labelpad=20)
         ax.set_ylim3d(0, 4)
-        ax.set_zlabel('Inverse MSE', fontsize = 11)
-        ax.set_zlim3d(0, 0.02)
+        ax.set_zlabel('Inverse MSE', fontsize = 14,labelpad=10)
+        ax.set_zlim3d(0, 1/MSESims[BestFit[0], 1])
         plt.yticks(zs, ParametersToSweep)
+        plt.plot([xb/np.max(SweepMatrix[:,0])],[1.], 1/MSESims[BestFit[0], 1], markerfacecolor='k', markeredgecolor='k', marker='o', markersize=4, alpha=0.6, label="Best fit")
+        plt.plot([yb/np.max(SweepMatrix[:,1])], [2.], 1/MSESims[BestFit[0], 1], markerfacecolor='k', markeredgecolor='k', marker='o', markersize=4,
+                 alpha=0.6)
+        plt.plot([kb/np.max(SweepMatrix[:,2])], [3.], 1/MSESims[BestFit[0], 1], markerfacecolor='k', markeredgecolor='k', marker='o', markersize=4,
+                 alpha=0.6)
+        plt.plot([xb/np.max(SweepMatrix[:,0]),yb/np.max(SweepMatrix[:,1]),kb/np.max(SweepMatrix[:,2])],[1.,2.,3.],[1/MSESims[BestFit[0], 1],
+                                            1/MSESims[BestFit[0], 1],1/MSESims[BestFit[0], 1]],'--',color='black')
+        plt.plot([xb / np.max(SweepMatrix[:, 0]),xb / np.max(SweepMatrix[:, 0])], [1.,1.], [0.,1/MSESims[BestFit[0], 1]],'--',color='r')
+        plt.plot([yb / np.max(SweepMatrix[:, 1]),yb / np.max(SweepMatrix[:, 1])], [2.,2.], [0.,1/MSESims[BestFit[0], 1]],'--',color='g')
+        plt.plot([kb / np.max(SweepMatrix[:, 2]),kb / np.max(SweepMatrix[:, 2])], [3.,3.], [0.,1/MSESims[BestFit[0], 1]],'--',color='y')
+        plt.legend()
         plt.show()
 
         ##Plot 3
@@ -296,14 +315,14 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
 
         fig = plt.figure()
         ax = fig.add_subplot(111, projection='3d')
-        ax.plot_surface(X, Y, Z, color='white', edgecolors='grey', alpha=0.5)
-        ax.scatter(X.flatten(), Y.flatten(), Z.flatten(), c='red')
+        ax.plot_surface(X, Y, np.transpose(Z), color='white', edgecolors='grey', alpha=0.5)
+        ax.scatter(X.flatten(), Y.flatten(), np.transpose(Z).flatten(), c='red')
         ax.set_xlabel(ParametersToSweep[Order[0]], fontsize =11)
         ax.set_ylabel(ParametersToSweep[Order[1]], fontsize =11)
         ax.set_zlabel('Inverse MSE', fontsize =16)
         plt.show()
 
-        ##Plot4
+        # # Plot4
         RData = np.max(RData, axis=1)
         fig = plt.figure()
         ax = fig.add_subplot(111, projection='3d')
